import cx from 'classnames';
import React, { MouseEvent } from 'react';
import styles from './calorieRow.css';
import { ItemActions } from './ItemActions';

type CalorieRowProps = {
  item: CalorieValue,
  onRowClick?: (item: CalorieValue) => void,
  removeItem: (itemToRemove: CalorieValue) => void,
  isSelected?: boolean
};

function CalorieRow (props: CalorieRowProps) {
  const {
    item,
    isSelected = false,
    onRowClick = Function.prototype,
    removeItem
  } = props;

  const onClick = (event: MouseEvent) => {
    event.stopPropagation();
    onRowClick(item);
  };

  return (
    <div className={cx(styles.calorieRow, {[styles.selected]: isSelected})} {...{onClick}}>
      <div className="itemValues">
        <div className={styles.title}>{item.title}</div>
        <div>{item.count}</div>
      </div>

      { isSelected && (
        <ItemActions {...{removeItem: () => removeItem(item)}} />
      )}
    </div>
  );
}

export {
  CalorieRow
};
